# Network Unified API Abstraction Library

> Note: This project is currently in the early phase of development

## Introduction

This project aims to bring multiple ways of communicating with networking gear under one unified API. This should allow network engineers to gather information about the network configuration in a fast and simple manner. In the early stage, this project focuses mainly on retrieving the information from the devices, not so much on performing configuration changes. 



## Where to get it

The PYPI package is not yet available, so please check the [GitHub](https://github.com/mijujda/nuaal) page for source files.

